==> realestate-supervise-common-1.0.0-20211126.015821-49-sources.jar: cn/gtmap/realestate/supervise/entity/BaQlr.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 权利人
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_qlr"
)

public class BaQlr implements Serializable {

    @Id
    @XmlAttribute
    @id
    private String id;

    @XmlAttribute
    private String ysdm;


    @XmlAttribute
    private String bdcdyh;

    @XmlAttribute
    private int sxh;

    @XmlAttribute
    @encrypt
    private String qlrmc;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    @Nullable
    private String qzysxlh;

    @XmlAttribute
    @Nullable
    private String sfczr;

    @XmlAttribute
    @Nullable
    private String zjzl;

    @XmlAttribute
    @Nullable
    @encrypt
    private String zjh;

    @XmlAttribute
    @Nullable
    private String fzjg;

    @XmlAttribute
    @Nullable
    private String sshy;

    @XmlAttribute
    private String gj;

    @XmlAttribute
    @Nullable
    private String hjszss;

    @XmlAttribute
    @Nullable
    private String xb;

    @XmlAttribute
    @Nullable
    private String dh;

    @XmlAttribute
    @Nullable
    private String dz;

    @XmlAttribute
    @Nullable
    private String yb;

    @XmlAttribute
    @Nullable
    private String gzdw;

    @XmlAttribute
    @Nullable
    private String dzyj;

    @XmlAttribute
    private String qlrlx;

    @XmlAttribute
    @Nullable
    private String qlbl;

    @XmlAttribute
    @Nullable
    private String gyfs;

    @XmlAttribute
    @Nullable
    private String gyqk;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    @ywh
    private String ywh;

    @Nullable
    private Date sjgxsj;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String qlrtz;

    @XmlAttribute
    private String cbfbm;

    @XmlAttribute
    private String fbfbm;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    private Date djsj;

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getQlrtz() {
        return qlrtz;
    }

    public void setQlrtz(String qlrtz) {
        this.qlrtz = qlrtz;
    }

    public String getCbfbm() {
        return cbfbm;
    }

    public void setCbfbm(String cbfbm) {
        this.cbfbm = cbfbm;
    }

    public String getFbfbm() {
        return fbfbm;
    }

    public void setFbfbm(String fbfbm) {
        this.fbfbm = fbfbm;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public int getSxh() {
        return sxh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQzysxlh() {
        return qzysxlh;
    }

    public String getSfczr() {
        return sfczr;
    }

    public String getZjzl() {
        return zjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public String getFzjg() {
        return fzjg;
    }

    public String getSshy() {
        return sshy;
    }

    public String getGj() {
        return gj;
    }

    public String getHjszss() {
        return hjszss;
    }


    public String getDh() {
        return dh;
    }

    public String getDz() {
        return dz;
    }

    public String getYb() {
        return yb;
    }

    public String getGzdw() {
        return gzdw;
    }

    public String getDzyj() {
        return dzyj;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public String getGyfs() {
        return gyfs;
    }

    public String getGyqk() {
        return gyqk;
    }

    public String getBz() {
        return bz;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQzysxlh(String qzysxlh) {
        this.qzysxlh = qzysxlh;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public void setZjzl(String zjzl) {
        this.zjzl = zjzl;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }

    public void setHjszss(String hjszss) {
        this.hjszss = hjszss;
    }


    public void setDh(String dh) {
        this.dh = dh;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

}

==> realestate-supervise-common-1.1.0-20250924.014108-69-sources.jar: cn/gtmap/realestate/supervise/entity/BaQlr.java <==
package cn.gtmap.realestate.supervise.entity;

import cn.gtmap.realestate.supervise.core.reflect.*;
import com.sun.istack.internal.Nullable;

import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.xml.bind.annotation.*;
import java.io.Serializable;
import java.util.Date;

/**
 * @author <a href="mailto:gaofeng@gtmap.cn">gaofeng</a>
 * @version 1.0，2017/6/15
 * @description 权利人
 */

@XmlAccessorType(XmlAccessType.FIELD)
@XmlRootElement
@XmlType
@Entity
@Table(
        name = "ba_qlr"
)

public class BaQlr implements Serializable {

    @Id
    @XmlAttribute
    @id
    private String id;

    @XmlAttribute
    private String ysdm;


    @XmlAttribute
    @bdcdyh
    private String bdcdyh;

    @XmlAttribute
    private int sxh;

    @XmlAttribute
    @encrypt
    private String qlrmc;

    @XmlAttribute
    private String bdcqzh;

    @XmlAttribute
    @Nullable
    private String qzysxlh;

    @XmlAttribute
    @Nullable
    private String sfczr;

    @XmlAttribute
    @Nullable
    private String zjzl;

    @XmlAttribute
    @Nullable
    @encrypt
    private String zjh;

    @XmlAttribute
    @Nullable
    private String fzjg;

    @XmlAttribute
    @Nullable
    private String sshy;

    @XmlAttribute
    private String gj;

    @XmlAttribute
    @Nullable
    private String hjszss;

    @XmlAttribute
    @Nullable
    private String xb;

    @XmlAttribute
    @Nullable
    private String dh;

    @XmlAttribute
    @Nullable
    private String dz;

    @XmlAttribute
    @Nullable
    private String yb;

    @XmlAttribute
    @Nullable
    private String gzdw;

    @XmlAttribute
    @Nullable
    private String dzyj;

    @XmlAttribute
    private String qlrlx;

    @XmlAttribute
    @Nullable
    private String qlbl;

    @XmlAttribute
    @Nullable
    private String gyfs;

    @XmlAttribute
    @Nullable
    private String gyqk;

    @XmlAttribute
    @Nullable
    private String bz;

    @XmlAttribute
    @ywh
    private String ywh;

    @Nullable
    private Date sjgxsj;

    @XmlAttribute
    @qxdm
    private String qxdm;

    @bwmc
    private String bwmc;

    @XmlAttribute
    private String qllx;

    @XmlAttribute
    private String qlrtz;

    @XmlAttribute
    private String cbfbm;

    @XmlAttribute
    private String fbfbm;

    @XmlAttribute
    private String qszt;

    @XmlAttribute
    private Date djsj;

    @sqlx
    private String sqlx;

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }


    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getQlrtz() {
        return qlrtz;
    }

    public void setQlrtz(String qlrtz) {
        this.qlrtz = qlrtz;
    }

    public String getCbfbm() {
        return cbfbm;
    }

    public void setCbfbm(String cbfbm) {
        this.cbfbm = cbfbm;
    }

    public String getFbfbm() {
        return fbfbm;
    }

    public void setFbfbm(String fbfbm) {
        this.fbfbm = fbfbm;
    }

    public String getQszt() {
        return qszt;
    }

    public void setQszt(String qszt) {
        this.qszt = qszt;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getBwmc() {
        return bwmc;
    }

    public void setBwmc(String bwmc) {
        this.bwmc = bwmc;
    }

    public String getYsdm() {
        return ysdm;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public int getSxh() {
        return sxh;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public String getBdcqzh() {
        return bdcqzh;
    }

    public String getQzysxlh() {
        return qzysxlh;
    }

    public String getSfczr() {
        return sfczr;
    }

    public String getZjzl() {
        return zjzl;
    }

    public String getZjh() {
        return zjh;
    }

    public String getFzjg() {
        return fzjg;
    }

    public String getSshy() {
        return sshy;
    }

    public String getGj() {
        return gj;
    }

    public String getHjszss() {
        return hjszss;
    }


    public String getDh() {
        return dh;
    }

    public String getDz() {
        return dz;
    }

    public String getYb() {
        return yb;
    }

    public String getGzdw() {
        return gzdw;
    }

    public String getDzyj() {
        return dzyj;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public String getGyfs() {
        return gyfs;
    }

    public String getGyqk() {
        return gyqk;
    }

    public String getBz() {
        return bz;
    }


    public void setYsdm(String ysdm) {
        this.ysdm = ysdm;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public void setSxh(int sxh) {
        this.sxh = sxh;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public void setBdcqzh(String bdcqzh) {
        this.bdcqzh = bdcqzh;
    }

    public void setQzysxlh(String qzysxlh) {
        this.qzysxlh = qzysxlh;
    }

    public void setSfczr(String sfczr) {
        this.sfczr = sfczr;
    }

    public void setZjzl(String zjzl) {
        this.zjzl = zjzl;
    }

    public void setZjh(String zjh) {
        this.zjh = zjh;
    }

    public void setFzjg(String fzjg) {
        this.fzjg = fzjg;
    }

    public void setSshy(String sshy) {
        this.sshy = sshy;
    }

    public void setGj(String gj) {
        this.gj = gj;
    }

    public void setHjszss(String hjszss) {
        this.hjszss = hjszss;
    }


    public void setDh(String dh) {
        this.dh = dh;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }

    public void setGzdw(String gzdw) {
        this.gzdw = gzdw;
    }

    public void setDzyj(String dzyj) {
        this.dzyj = dzyj;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public void setGyfs(String gyfs) {
        this.gyfs = gyfs;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getId() {
        return id;
    }

    public void setId(String id) {
        this.id = id;
    }

    public String getYwh() {
        return ywh;
    }

    public void setYwh(String ywh) {
        this.ywh = ywh;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public Date getSjgxsj() {
        return sjgxsj;
    }

    public void setSjgxsj(Date sjgxsj) {
        this.sjgxsj = sjgxsj;
    }

    public String getQxdm() {
        return qxdm;
    }

    public void setQxdm(String qxdm) {
        this.qxdm = qxdm;
    }

}
